Various, unrelated tree-wide typo fixes.
authorRobert P. J. Day <rpjday@crashcourse.ca>
Fri, 15 Jul 2016 17:44:45 +0000 (13:44 -0400)
committerTom Rini <trini@konsulko.com>
Sat, 16 Jul 2016 13:43:12 +0000 (09:43 -0400)
    Fix a number of typos, including:

     * "compatble" -> "compatible"
     * "eanbeld" -> "enabled"
     * "envrionment" -> "environment"
     * "FTD" -> "FDT" (for "flattened device tree")
     * "ommitted" -> "omitted"
     * "overriden" -> "overridden"
     * "partiton" -> "partition"
     * "propogate" -> "propagate"
     * "resourse" -> "resource"
     * "rest in piece" -> "rest in peace"
     * "suport" -> "support"
     * "varible" -> "variable"

Signed-off-by: Robert P. J. Day <rpjday@crashcourse.ca>
35 files changed:
README
arch/arm/cpu/armv7/Kconfig
arch/arm/cpu/armv8/fsl-layerscape/doc/README.lsch3
arch/arm/cpu/armv8/zynqmp/mp.c
arch/arm/imx-common/ddrmc-vf610.c
arch/arm/include/asm/arch-tegra/board.h
arch/arm/include/asm/arch-tegra/clock.h
arch/arm/include/asm/arch-tegra124/display.h
arch/arm/mach-tegra/clock.c
arch/powerpc/cpu/mpc85xx/mp.c
arch/powerpc/cpu/ppc4xx/start.S
arch/powerpc/include/asm/status_led.h
board/keymile/common/common.c
board/keymile/kmp204x/ddr.c
cmd/i2c.c
common/env_common.c
doc/README.gpt
doc/README.scrapyard
doc/feature-removal-schedule.txt
drivers/bios_emulator/x86emu/sys.c
drivers/crypto/fsl/desc.h
drivers/ddr/fsl/ctrl_regs.c
drivers/fpga/fpga.c
drivers/mmc/Kconfig
drivers/mtd/nand/mxs_nand.c
drivers/mtd/nand/tegra_nand.c
drivers/usb/musb-new/musb_dsps.c
drivers/video/tegra.c
include/configs/mxs.h
include/configs/v38b.h
include/net.h
lib/hashtable.c
net/eth_internal.h
post/cpu/ppc4xx/ether.c
tools/env/fw_env.config

diff --git a/README b/README
index e906253fa2b03dafa7dc20a3f41bec5854c9af0d..3c3b699a1f75ef2091ae63ee4a25e5fb8b40070b 100644 (file)
--- a/README
+++ b/README
@@ -511,7 +511,7 @@ The following options need to be configured:
                implemetation.
 
                CONFIG_SYS_FSL_DDR2
-               Board config to use DDR2. It can be eanbeld for SoCs with
+               Board config to use DDR2. It can be enabled for SoCs with
                Freescale DDR2 or DDR3 controllers, depending on the board
                implementation.
 
index afeaac84dec1016b090bb6f41bca613daee8547c..bd6108eec06caf2118f6f792c7baa02f387228f3 100644 (file)
@@ -21,7 +21,7 @@ config ARMV7_BOOT_SEC_DEFAULT
        Say Y here to boot in secure mode by default even if non-secure mode
        is supported. This option is useful to boot kernels which do not
        suppport booting in non-secure mode. Only set this if you need it.
-       This can be overriden at run-time by setting the bootm_boot_mode env.
+       This can be overridden at run-time by setting the bootm_boot_mode env.
        variable to "sec" or "nonsec".
 
 config ARMV7_VIRT
index da5e052569c49bcd5bab96b0fee1cc2c981ebba7..7867c379d4b3ea8765a44ee0f362d759ac663e68 100644 (file)
@@ -128,7 +128,7 @@ mcinitcmd:  This environment variable is defined to initiate MC and DPL deploymen
                during U-boot booting.However the MC, DPC and DPL can be applied from
                console independently.
                The variable needs to be set from the console once and then on
-               rebooting the parameters set in the varible will automatically be
+               rebooting the parameters set in the variable will automatically be
                executed. The commmand is demostrated taking an example of mc boot
                using NOR Flash i.e. MC, DPL, and DPC is stored in the NOR flash:
 
index 58312a79bc59b9b6edf06e59bce1f6d6a5e8a0c3..e10fc3136c85b3958ecfbccbce9a6ed0a20407ec 100644 (file)
@@ -128,7 +128,7 @@ static void enable_clock_r5(void)
        writel(tmp, &crlapb_base->cpu_r5_ctrl);
 
        /* Give some delay for clock
-        * to propogate */
+        * to propagate */
        udelay(0x500);
 }
 
index daf3c7ebfaf29e9c0611f7e005f000cb25f327be..9bc56f6ac13bada1411d2dae218ff392641f6db0 100644 (file)
@@ -212,7 +212,7 @@ void ddrmc_ctrl_init_ddr3(struct ddr3_jedec_timings const *timings,
                        cr_setting++;
                }
 
-       /* perform default PHY settings (may be overriden by custom settings */
+       /* perform default PHY settings (may be overridden by custom settings */
        phy_setting = default_phy_settings;
        while (phy_setting->phy_rnum >= 0) {
                writel(phy_setting->setting,
index 783bb3c0fa12265901fdd3b99c9f2cc008486a83..a3db7ed6044127c4343136f54ee70c525d6013fa 100644 (file)
@@ -20,7 +20,7 @@ void gpio_early_init(void);  /* overrideable GPIO config        */
 /*
  * Hooks to allow boards to set up the pinmux for a specific function.
  * Has to be implemented in the board files as we don't yet support pinmux
- * setup from FTD. If a board file does not implement one of those functions
+ * setup from FDT. If a board file does not implement one of those functions
  * an empty stub function will be called.
  */
 
index e56031d1afa7e8bd5508447be3e2c16aa0d9417b..7daf8bc1632a6076fff33bf04c508b36ba627ce1 100644 (file)
@@ -324,7 +324,7 @@ enum periph_id clk_id_to_periph_id(int clk_id);
  * @param p post divider(DIVP)
  * @param cpcon base PLL charge pump(CPCON)
  * @return 0 if ok, -1 on error (the requested PLL is incorrect and cannot
- *              be overriden), 1 if PLL is already correct
+ *              be overridden), 1 if PLL is already correct
  */
 int clock_set_rate(enum clock_id clkid, u32 n, u32 m, u32 p, u32 cpcon);
 
index ca6644af345b6d6cb52dedd99636766a853fcf30..c522faa93678cf73bcc574b68dad8836632ac470 100644 (file)
@@ -11,7 +11,7 @@
 /**
  * Register a new display based on device tree configuration.
  *
- * The frame buffer can be positioned by U-Boot or overriden by the fdt.
+ * The frame buffer can be positioned by U-Boot or overridden by the fdt.
  * You should pass in the U-Boot address here, and check the contents of
  * struct fdt_disp_config to see what was actually chosen.
  *
index c50d56dc888b5f612604832b22045b317cfdc93c..36eabc8f5721125a6708573ab2b0755822df23a6 100644 (file)
@@ -510,7 +510,7 @@ unsigned clock_get_rate(enum clock_id clkid)
  * @param p post divider(DIVP)
  * @param cpcon base PLL charge pump(CPCON)
  * @return 0 if ok, -1 on error (the requested PLL is incorrect and cannot
- *             be overriden), 1 if PLL is already correct
+ *             be overridden), 1 if PLL is already correct
  */
 int clock_set_rate(enum clock_id clkid, u32 n, u32 m, u32 p, u32 cpcon)
 {
index 88c8e65930e6918002fd8495fb4dc9644f704e53..0addf8493c2577bbd6d07e66c383f2eb3e3f422c 100644 (file)
@@ -30,7 +30,7 @@ u32 get_my_id()
  */
 int hold_cores_in_reset(int verbose)
 {
-       /* Default to no, overriden by 'y', 'yes', 'Y', 'Yes', or '1' */
+       /* Default to no, overridden by 'y', 'yes', 'Y', 'Yes', or '1' */
        if (getenv_yesno("mp_holdoff") == 1) {
                if (verbose) {
                        puts("Secondary cores are being held in reset.\n");
index b432b18c74d6939d735829d11696f50938a17c0f..5647d712d6d4e43025ca13e831a736548628e0ac 100644 (file)
 #endif
 
 /*
- * Unless otherwise overriden, enable two 128MB cachable instruction regions
+ * Unless otherwise overridden, enable two 128MB cachable instruction regions
  * at CONFIG_SYS_SDRAM_BASE and another 128MB cacheable instruction region covering
  * NOR flash at CONFIG_SYS_FLASH_BASE. Disable all cacheable data regions.
  */
index 441619042d21bb86f0cbd8df1163d201c48fdc46..260a8319ce34ccf228ecac69742d6febe4015b86 100644 (file)
@@ -7,7 +7,7 @@
 #ifndef __ASM_STATUS_LED_H__
 #define __ASM_STATUS_LED_H__
 
-/* if not overriden */
+/* if not overridden */
 #ifndef CONFIG_BOARD_SPECIFIC_LED
 # if defined(CONFIG_8xx)
 #  include <mpc8xx.h>
index a42f3eca33b3f22b1721879da42116d03b9f7d99..0829b7fa0666574ed2f82bdd0a8c5e48001cf404 100644 (file)
@@ -53,7 +53,7 @@ int set_km_env(void)
        sprintf((char *)buf, "0x%x", pnvramaddr);
        setenv("pnvramaddr", (char *)buf);
 
-       /* try to read rootfssize (ram image) from envrionment */
+       /* try to read rootfssize (ram image) from environment */
        p = getenv("rootfssize");
        if (p != NULL)
                strict_strtoul(p, 16, &rootfssize);
index 34ac6979bd7d13c602f47f8ef218e9123d39ba02..77af184c82b5effc4863f8d10618db849501ab38 100644 (file)
@@ -36,7 +36,7 @@ void fsl_ddr_board_options(memctl_options_t *popts,
        /* we have only one module, half str should be OK */
        popts->half_strength_driver_enable = 1;
 
-       /* wrlvl values overriden as recommended by ddr init func */
+       /* wrlvl values overridden as recommended by ddr init func */
        popts->wrlvl_override = 1;
        popts->wrlvl_sample = 0xf;
        popts->wrlvl_start = 0x6;
index 18ce789d7edd916bd704e776b70afedaa3b446d7..473153fbd4737a7949a3f22b0c5a29b7009b941b 100644 (file)
--- a/cmd/i2c.c
+++ b/cmd/i2c.c
@@ -178,7 +178,7 @@ static int i2c_get_cur_bus_chip(uint chip_addr, struct udevice **devp)
  * i2c_init_board() - Board-specific I2C bus init
  *
  * This function is the default no-op implementation of I2C bus
- * initialization. This function can be overriden by board-specific
+ * initialization. This function can be overridden by board-specific
  * implementation if needed.
  */
 __weak
index 13db7dc3f7553fc909618462a376b829e1a194c6..560cad02476404fdde6e4f0b4dff5f07a7ec22d1 100644 (file)
@@ -145,7 +145,7 @@ int set_default_vars(int nvars, char * const vars[])
  * env_aes_cbc_get_key() - Get AES-128-CBC key for the environment
  *
  * This function shall return 16-byte array containing AES-128 key used
- * to encrypt and decrypt the environment. This function must be overriden
+ * to encrypt and decrypt the environment. This function must be overridden
  * by the implementer as otherwise the environment encryption will not
  * work.
  */
index a6f6de6a0f5f78549689f148844b708aac5b4b3e..3fcd83557f99bee1ec60d62646b9bc3c99c49951 100644 (file)
@@ -165,7 +165,7 @@ To restore GUID partition table one needs to:
    The fields 'name' and 'size' are mandatory for every partition.
    The field 'start' is optional.
 
-   If field 'size' of the last partition is 0, the partiton is extended
+   If field 'size' of the last partition is 0, the partition is extended
    up to the end of the device.
 
    The fields 'uuid' and 'uuid_disk' are optional if CONFIG_RANDOM_UUID is
index b7cf62df9b4da53a886ebb01ea82bc940b5d34e6..200f6708060b8e0f4090e60b47a5cb7dfc4fd8e9 100644 (file)
@@ -3,7 +3,7 @@ while other board support code dies a silent death caused by
 negligence in combination with ordinary bitrot.  Sometimes this goes
 by unnoticed, but often build errors will result.  If nobody cares any
 more to resolve such problems, then the code is really dead and will
-be removed from the U-Boot source tree.  The remainders rest in piece
+be removed from the U-Boot source tree.  The remainders rest in peace
 in the imperishable depths of the git history.  This document tries to
 maintain a list of such former fellows, so archaeologists can check
 easily if there is something they might want to dig for...
index 4ed30df707ecd8f32b1e62d60c98cf695378efd3..b5a70da2962a527216cad4abf58b971cd7b14e2d 100644 (file)
@@ -12,7 +12,7 @@ When: Release v2013.10
 
 Why:   As the 'mtest' command is no longer default, a number of platforms
        have not opted to turn the command back on and thus provide unused
-       defines (which are likely to be propogated to new platforms from
+       defines (which are likely to be propagated to new platforms from
        copy/paste).  Remove these defines when unused.
 
 Who:   Tom Rini <trini@ti.com>
index 0ba9c0c105dd14cd2c17614da5ff71e84efca7c1..c2db1213fe66262145e6f790a75aef2012c6ceac 100644 (file)
@@ -35,7 +35,7 @@
 * Description:  This file includes subroutines which are related to
 *               programmed I/O and memory access. Included in this module
 *               are default functions that do nothing. For real uses these
-*               functions will have to be overriden by the user library.
+*               functions will have to be overridden by the user library.
 *
 ****************************************************************************/
 
index 1ac3a09dffe275f6e2e1dbb2abf79c9113705d80..081bce53cff2290aff7cad871b83676cc2b52a47 100644 (file)
  */
 #define HDR_REVERSE            0x00000800
 
-/* Propogate DNR property to SharedDesc */
+/* Propagate DNR property to SharedDesc */
 #define HDR_PROP_DNR           0x00000800
 
 /* JobDesc/SharedDesc share property */
index 1d5cec662ce1c94f4af5ca9282aa457e3ace1473..abd576b9350787c3e2db3a181688ca8f38c8cc1f 100644 (file)
@@ -2212,7 +2212,7 @@ static void set_ddr_wrlvl_cntl(fsl_ddr_cfg_regs_t *ddr, unsigned int wrlvl_en,
                 * Write leveling start time
                 * The value use for the DQS_ADJUST for the first sample
                 * when write leveling is enabled. It probably needs to be
-                * overriden per platform.
+                * overridden per platform.
                 */
                wrlvl_start = 0x8;
                /*
index 7e2f3e17a7649a6bdddb3e41eef6f75c660b3c7c..e0fb1b4e783b7527bf43185cf7c053fc7c3fa0d9 100644 (file)
@@ -31,7 +31,7 @@ static void fpga_no_sup(char *fn, char *msg)
        else if (msg)
                printf("No support for %s.\n", msg);
        else
-               printf("No FPGA suport!\n");
+               printf("No FPGA support!\n");
 }
 
 
index 79cf18f14f81faff739ebff41bd88a3c4ce1a435..e0adb9b1a3e49781bf88b2a2493f0358e77d14bb 100644 (file)
@@ -10,7 +10,7 @@ config DM_MMC
        bool "Enable MMC controllers using Driver Model"
        depends on DM
        help
-         This enables the MultiMediaCard (MMC) uclass which suports MMC and
+         This enables the MultiMediaCard (MMC) uclass which supports MMC and
          Secure Digital I/O (SDIO) cards. Both removable (SD, micro-SD, etc.)
          and non-removable (e.g. eMMC chip) devices are supported. These
          appear as block devices in U-Boot and can support filesystems such
index c90a3a7bd2cb596f5bd5d7ea75a5454faa12418c..94fc5c18a0765e6c401afec22b3bdad0ce181bf4 100644 (file)
@@ -976,7 +976,7 @@ static int mxs_nand_block_bad(struct mtd_info *mtd, loff_t ofs)
  * counted, so we know the physical geometry. This enables us to make some
  * important configuration decisions.
  *
- * The return value of this function propogates directly back to this driver's
+ * The return value of this function propagates directly back to this driver's
  * call to nand_scan(). Anything other than zero will cause this driver to
  * tear everything down and declare failure.
  */
index 2032f658129c5b5608d2f5d8b433bc5fb565c10f..38bd7a5578b37227cd637e38338bf2e378e35b74 100644 (file)
@@ -884,7 +884,7 @@ static void setup_timing(unsigned timing[FDT_NAND_TIMING_COUNT],
  * Decode NAND parameters from the device tree
  *
  * @param blob Device tree blob
- * @param node Node containing "nand-flash" compatble node
+ * @param node Node containing "nand-flash" compatible node
  * @return 0 if ok, -ve on error (FDT_ERR_...)
  */
 static int fdt_decode_nand(const void *blob, int node, struct fdt_nand *config)
index bb7c9522927e3ceac46c58845ba236752ab727cd..a71db76d7c7c4b44c073dda60ddfaa13c82951ad 100644 (file)
@@ -627,7 +627,7 @@ static int __devinit dsps_probe(struct platform_device *pdev)
        /* get memory resource */
        iomem = platform_get_resource(pdev, IORESOURCE_MEM, 0);
        if (!iomem) {
-               dev_err(&pdev->dev, "failed to get usbss mem resourse\n");
+               dev_err(&pdev->dev, "failed to get usbss mem resource\n");
                ret = -ENODEV;
                goto err1;
        }
index 217f05f9e2ec26cfc90acbf48b154b672723c4bd..92214d61b279210e173c845b058a0fe94ea2a952 100644 (file)
@@ -251,7 +251,7 @@ static int setup_window(struct disp_ctl_win *win,
 /**
  * Register a new display based on device tree configuration.
  *
- * The frame buffer can be positioned by U-Boot or overriden by the fdt.
+ * The frame buffer can be positioned by U-Boot or overridden by the fdt.
  * You should pass in the U-Boot address here, and check the contents of
  * struct tegra_lcd_priv to see what was actually chosen.
  *
index 0882d5d8f2d5f84a47cb6183d13d7a808125cd20..238b16d17f1785c28c86723ed63fcd4b456397ac 100644 (file)
 #define CONFIG_PL011_CLOCK             24000000
 #define CONFIG_PL01x_PORTS             { (void *)MXS_UARTDBG_BASE }
 #define CONFIG_CONS_INDEX              0
-/* Default baudrate can be overriden by board! */
+/* Default baudrate can be overridden by board! */
 #ifndef CONFIG_BAUDRATE
 #define CONFIG_BAUDRATE                        115200
 #endif
index 28c748d074c7e4b930a665f8fbcf020214edec22..5ebdf5b40240076c5c62d76a042ec1d38a0b21bf 100644 (file)
@@ -55,7 +55,7 @@
 #define SDRAM_TAPDELAY         0x10000000
 
 /*
* PCI - no suport
  */
 #undef CONFIG_PCI
 
index 5ee5929beb8626dab694e838e8735324e17062f8..06320c6514c9543923f109a0300e8e0e91a78057 100644 (file)
@@ -238,7 +238,7 @@ int eth_getenv_enetaddr(const char *name, uchar *enetaddr);
 int eth_setenv_enetaddr(const char *name, const uchar *enetaddr);
 
 /**
- * eth_setenv_enetaddr_by_index() - set the MAC address envrionment variable
+ * eth_setenv_enetaddr_by_index() - set the MAC address environment variable
  *
  * This sets up an environment variable with the given MAC address (@enetaddr).
  * The environment variable to be set is defined by <@base_name><@index>addr.
index 02b41050a44f6656e9605e288f5f6a97faf3539c..435e2a6ac14591158da3bf9fe50dd4f1c1382695 100644 (file)
@@ -822,7 +822,7 @@ int himport_r(struct hsearch_data *htab,
         * (CONFIG_ENV_SIZE).  This heuristics will result in
         * unreasonably large numbers (and thus memory footprint) for
         * big flash environments (>8,000 entries for 64 KB
-        * envrionment size), so we clip it to a reasonable value.
+        * environment size), so we clip it to a reasonable value.
         * On the other hand we need to add some more entries for free
         * space when importing very small buffers. Both boundaries can
         * be overwritten in the board config file if needed.
index 6e4753cd0dd0d0570a71c67b7e466a55571ec875..a14b20844f896148be0af43aad950ba36e69ea8e 100644 (file)
@@ -13,7 +13,7 @@
 void eth_common_init(void);
 
 /**
- * eth_setenv_enetaddr_by_index() - set the MAC address envrionment variable
+ * eth_setenv_enetaddr_by_index() - set the MAC address environment variable
  *
  * This sets up an environment variable with the given MAC address (@enetaddr).
  * The environment variable to be set is defined by <@base_name><@index>addr.
index 4c9a39b52675759b23850de1f8c0384d6db51251..8a4c56b7d622ead7495710294a3a64b69a88b352 100644 (file)
@@ -21,7 +21,7 @@
  *   CONFIG_SYS_POST_ETH_LOOPS - Number of test loops. Each loop
  *     is tested with a different frame length. Starting with
  *     MAX_PACKET_LENGTH and going down to MIN_PACKET_LENGTH.
- *     Defaults to 10 and can be overriden in the board config header.
+ *     Defaults to 10 and can be overridden in the board config header.
  */
 
 #include <post.h>
index 6f216f9c64c6ec1acf40fcc28fe2af08a4e9ffaf..776e16f784c59934c29b42237bacc80c9ab60a68 100644 (file)
@@ -2,7 +2,7 @@
 # Up to two entries are valid, in this case the redundant
 # environment sector is assumed present.
 # Notice, that the "Number of sectors" is not required on NOR and SPI-dataflash.
-# Futhermore, if the Flash sector size is ommitted, this value is assumed to
+# Futhermore, if the Flash sector size is omitted, this value is assumed to
 # be the same as the Environment size, which is valid for NOR and SPI-dataflash
 
 # NOR example
@@ -55,7 +55,7 @@
 
 /*
- * PCI - no suport
+ * PCI - no support
  */
 #undef CONFIG_PCI